@@ -11,11 +11,19 @@ import json
 
 # Third party packages
 import pandas as pd
-
+import pickle
 # Local packages
 
 __all__ = ['NaPoleonXConnector']
 
+def save_pickled_list(list_to_save = None, local_root_directory= '../data/', list_pkl_file_name = 'my_list.pkl'):
+    with open(local_root_directory+list_pkl_file_name, 'wb') as f:
+        pickle.dump(list_to_save, f)
+
+def load_pickled_list( local_root_directory= '../data/', list_pkl_file_name = 'my_list.pkl'):
+    with open(local_root_directory+list_pkl_file_name, 'rb') as f:
+        my_list = pickle.load(f)
+    return my_list
 
 def fetch_crypto_hourly_data(ssj=None, pickle_saving_path=None, refetch_all=True):
     if refetch_all:
@@ -89,6 +97,28 @@ def fetch_crypto_hourly_data(ssj=None, pickle_saving_path=None, refetch_all=True
             'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts5))
         df = pd.DataFrame(json.loads(r.text)['Data'])
         dataframe = dataframe.append(df, ignore_index=True)
+        time.sleep(1)
+        r = requests.get(
+            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts4))
+        df = pd.DataFrame(json.loads(r.text)['Data'])
+        dataframe = dataframe.append(df, ignore_index=True)
+        r = requests.get(
+            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts3))
+        df = pd.DataFrame(json.loads(r.text)['Data'])
+        dataframe = dataframe.append(df, ignore_index=True)
+        r = requests.get(
+            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts2))
+        df = pd.DataFrame(json.loads(r.text)['Data'])
+        dataframe = dataframe.append(df, ignore_index=True)
+        r = requests.get(
+            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts1))
+        df = pd.DataFrame(json.loads(r.text)['Data'])
+        dataframe = dataframe.append(df, ignore_index=True)
+        r = requests.get(
+            'https://min-api.cryptocompare.com/data/histohour?fsym={}&tsym=USD&toTs={}&limit=2000'.format(ssj, ts))
+        df = pd.DataFrame(json.loads(r.text)['Data'])
+        dataframe = dataframe.append(df, ignore_index=True)
+
         dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
         dataframe = dataframe.sort_values(by=['time'])
         dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
