@@ -56,12 +56,13 @@ class AbstractRunner(ABC):
         pass
 
 class SimpleSignalRunner(AbstractRunner):
-    def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs):
+    def runTrial(self, saver, seed, trigger, signal_type, idios_string, transaction_costs, normalization):
         idios = json.loads(idios_string)
         common_params ={
             'trigger' : trigger,
             'signal_type' : signal_type,
-            'transaction_costs' :transaction_costs
+            'transaction_costs' : transaction_costs,
+            'normalization' : normalization
         }
         common_params.update(idios)
         saving_key = json.dumps(common_params, sort_keys=True)
@@ -89,7 +90,7 @@ class SimpleSignalRunner(AbstractRunner):
             signal_generation_method_to_call = getattr(signal_generator, signal_type)
             hourly_df = roll_wrapper(hourly_df, lookback_window, skipping_size,
                                       lambda x: signal_generation_method_to_call(data=x, **idios), trigger)
-        hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs)
+        hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs , normalization = normalization)
         sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period= 252 * 24, from_ret=True)
         sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period= 252 * 24, from_ret=True)
         print('underlying sharpe')
